/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 1.3.40
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package zxidjava;

class zxidjniJNI {
  public final static native int ZXERR_EOF_get();
  public final static native int ZXERR_MISMATCH_CLOSE_get();
  public final static native int ZXERR_BAD_ATTR_NS_get();
  public final static native int ZXERR_BAD_ELEM_NS_get();
  public final static native int ZXERR_MISSING_ATTR_get();
  public final static native int ZXERR_EXTRA_ATTR_get();
  public final static native int ZXERR_MISSING_ELEM_get();
  public final static native int ZXERR_EXTRA_ELEM_get();
  public final static native int ZXERR_ELEM_ORDER_get();
  public final static native int ZXERR_BAD_NS_PREFIX_get();
  public final static native int ZXERR_TAG_NOT_CLOSED_get();
  public final static native int ZXERR_MASK_get();
  public final static native int ZXERR_ATTR_FLAG_get();
  public final static native void zx_ns_s_n_set(long jarg1, long jarg2);
  public final static native long zx_ns_s_n_get(long jarg1);
  public final static native void zx_ns_s_m_set(long jarg1, long jarg2);
  public final static native long zx_ns_s_m_get(long jarg1);
  public final static native void zx_ns_s_seen_set(long jarg1, long jarg2);
  public final static native long zx_ns_s_seen_get(long jarg1);
  public final static native void zx_ns_s_seen_n_set(long jarg1, long jarg2);
  public final static native long zx_ns_s_seen_n_get(long jarg1);
  public final static native void zx_ns_s_seen_p_set(long jarg1, long jarg2);
  public final static native long zx_ns_s_seen_p_get(long jarg1);
  public final static native void zx_ns_s_seen_pop_set(long jarg1, long jarg2);
  public final static native long zx_ns_s_seen_pop_get(long jarg1);
  public final static native void zx_ns_s_inc_n_set(long jarg1, long jarg2);
  public final static native long zx_ns_s_inc_n_get(long jarg1);
  public final static native void zx_ns_s_prefix_len_set(long jarg1, int jarg2);
  public final static native int zx_ns_s_prefix_len_get(long jarg1);
  public final static native void zx_ns_s_prefix_set(long jarg1, String jarg2);
  public final static native String zx_ns_s_prefix_get(long jarg1);
  public final static native void zx_ns_s_url_len_set(long jarg1, int jarg2);
  public final static native int zx_ns_s_url_len_get(long jarg1);
  public final static native void zx_ns_s_url_set(long jarg1, String jarg2);
  public final static native String zx_ns_s_url_get(long jarg1);
  public final static native long new_zx_ns_s();
  public final static native void delete_zx_ns_s(long jarg1);
  public final static native void zx_ctx_base_set(long jarg1, String jarg2);
  public final static native String zx_ctx_base_get(long jarg1);
  public final static native void zx_ctx_p_set(long jarg1, String jarg2);
  public final static native String zx_ctx_p_get(long jarg1);
  public final static native void zx_ctx_lim_set(long jarg1, String jarg2);
  public final static native String zx_ctx_lim_get(long jarg1);
  public final static native void zx_ctx_ns_tab_set(long jarg1, long jarg2);
  public final static native long zx_ctx_ns_tab_get(long jarg1);
  public final static native void zx_ctx_unknown_ns_set(long jarg1, long jarg2);
  public final static native long zx_ctx_unknown_ns_get(long jarg1);
  public final static native void zx_ctx_guard_seen_n_set(long jarg1, long jarg2);
  public final static native long zx_ctx_guard_seen_n_get(long jarg1);
  public final static native void zx_ctx_guard_seen_p_set(long jarg1, long jarg2);
  public final static native long zx_ctx_guard_seen_p_get(long jarg1);
  public final static native void zx_ctx_exclude_sig_set(long jarg1, long jarg2);
  public final static native long zx_ctx_exclude_sig_get(long jarg1);
  public final static native void zx_ctx_inc_ns_len_set(long jarg1, long jarg2);
  public final static native long zx_ctx_inc_ns_len_get(long jarg1);
  public final static native void zx_ctx_inc_ns_set(long jarg1, long jarg2);
  public final static native long zx_ctx_inc_ns_get(long jarg1);
  public final static native void zx_ctx_malloc_func_set(long jarg1, long jarg2);
  public final static native long zx_ctx_malloc_func_get(long jarg1);
  public final static native void zx_ctx_realloc_func_set(long jarg1, long jarg2);
  public final static native long zx_ctx_realloc_func_get(long jarg1);
  public final static native void zx_ctx_free_func_set(long jarg1, long jarg2);
  public final static native long zx_ctx_free_func_get(long jarg1);
  public final static native long new_zx_ctx();
  public final static native void delete_zx_ctx(long jarg1);
  public final static native void zx_node_s_n_set(long jarg1, long jarg2);
  public final static native long zx_node_s_n_get(long jarg1);
  public final static native void zx_node_s_wo_set(long jarg1, long jarg2);
  public final static native long zx_node_s_wo_get(long jarg1);
  public final static native void zx_node_s_ns_set(long jarg1, long jarg2);
  public final static native long zx_node_s_ns_get(long jarg1);
  public final static native void zx_node_s_tok_set(long jarg1, short jarg2);
  public final static native short zx_node_s_tok_get(long jarg1);
  public final static native void zx_node_s_err_set(long jarg1, short jarg2);
  public final static native short zx_node_s_err_get(long jarg1);
  public final static native long new_zx_node_s();
  public final static native void delete_zx_node_s(long jarg1);
  public final static native void zx_elem_s_g_set(long jarg1, long jarg2);
  public final static native long zx_elem_s_g_get(long jarg1);
  public final static native void zx_elem_s_kids_set(long jarg1, long jarg2);
  public final static native long zx_elem_s_kids_get(long jarg1);
  public final static native void zx_elem_s_any_attr_set(long jarg1, long jarg2);
  public final static native long zx_elem_s_any_attr_get(long jarg1);
  public final static native void zx_elem_s_any_elem_set(long jarg1, long jarg2);
  public final static native long zx_elem_s_any_elem_get(long jarg1);
  public final static native void zx_elem_s_xmlns_set(long jarg1, String jarg2);
  public final static native String zx_elem_s_xmlns_get(long jarg1);
  public final static native void zx_elem_s_content_set(long jarg1, String jarg2);
  public final static native String zx_elem_s_content_get(long jarg1);
  public final static native long new_zx_elem_s();
  public final static native void delete_zx_elem_s(long jarg1);
  public final static native long zx_new_simple_elem(long jarg1, String jarg2);
  public final static native long zx_ref_len_simple_elem(long jarg1, int jarg2);
  public final static native long zx_ref_simple_elem(long jarg1, String jarg2);
  public final static native long zx_dup_len_simple_elem(long jarg1, int jarg2);
  public final static native long zx_dup_simple_elem(long jarg1, String jarg2);
  public final static native void zx_str_g_set(String jarg1, long jarg2);
  public final static native long zx_str_g_get(String jarg1);
  public final static native void zx_str_len_set(String jarg1, int jarg2);
  public final static native int zx_str_len_get(String jarg1);
  public final static native void zx_str_s_set(String jarg1, String jarg2);
  public final static native String zx_str_s_get(String jarg1);
  public final static native String new_zx_str();
  public final static native void delete_zx_str(String jarg1);
  public final static native String zx_ref_str(long jarg1, String jarg2);
  public final static native String zx_ref_len_str(long jarg1, int jarg2);
  public final static native String zx_new_len_str(long jarg1, int jarg2);
  public final static native String zx_dup_str(long jarg1, String jarg2);
  public final static native String zx_dup_len_str(long jarg1, int jarg2);
  public final static native String zx_alloc_sprintf(long jarg1, long jarg2, String jarg3);
  public final static native String zx_strf(long jarg1, String jarg2);
  public final static native void zx_str_free(long jarg1, String jarg2);
  public final static native String zx_str_to_c(long jarg1, String jarg2);
  public final static native void zx_str_conv(String jarg1, long jarg2, long jarg3);
  public final static native int zx_str_ends_in(String jarg1, int jarg2, String jarg3);
  public final static native void zx_any_elem_s_gg_set(long jarg1, long jarg2);
  public final static native long zx_any_elem_s_gg_get(long jarg1);
  public final static native void zx_any_elem_s_name_len_set(long jarg1, int jarg2);
  public final static native int zx_any_elem_s_name_len_get(long jarg1);
  public final static native void zx_any_elem_s_name_set(long jarg1, String jarg2);
  public final static native String zx_any_elem_s_name_get(long jarg1);
  public final static native long new_zx_any_elem_s();
  public final static native void delete_zx_any_elem_s(long jarg1);
  public final static native void zx_any_attr_s_ss_set(long jarg1, String jarg2);
  public final static native String zx_any_attr_s_ss_get(long jarg1);
  public final static native void zx_any_attr_s_name_len_set(long jarg1, int jarg2);
  public final static native int zx_any_attr_s_name_len_get(long jarg1);
  public final static native void zx_any_attr_s_name_set(long jarg1, String jarg2);
  public final static native String zx_any_attr_s_name_get(long jarg1);
  public final static native long new_zx_any_attr_s();
  public final static native void delete_zx_any_attr_s(long jarg1);
  public final static native String zx_memmem(String jarg1, int jarg2, String jarg3, int jarg4);
  public final static native long zx_alloc(long jarg1, int jarg2);
  public final static native long zx_zalloc(long jarg1, int jarg2);
  public final static native long zx_free(long jarg1, long jarg2);
  public final static native String zx_dup_cstr(long jarg1, String jarg2);
  public final static native void zx_reset_ctx(long jarg1);
  public final static native long zx_init_ctx();
  public final static native int ZX_TOK_XMLNS_get();
  public final static native int ZX_TOK_DATA_get();
  public final static native int ZX_TOK_NOT_FOUND_get();
  public final static native void zx_tok_name_set(long jarg1, String jarg2);
  public final static native String zx_tok_name_get(long jarg1);
  public final static native void zx_tok_prefix_set(long jarg1, String jarg2);
  public final static native String zx_tok_prefix_get(long jarg1);
  public final static native void zx_tok_ns_set(long jarg1, long jarg2);
  public final static native long zx_tok_ns_get(long jarg1);
  public final static native long new_zx_tok();
  public final static native void delete_zx_tok(long jarg1);
  public final static native int zx_date_time_to_secs(String jarg1);
  public final static native int write2_or_append_lock_c_path(String jarg1, int jarg2, String jarg3, int jarg4, String jarg5, String jarg6, int jarg7, int jarg8);
  public final static native int zx_report_openssl_error(String jarg1);
  public final static native void zx_fix_any_elem_dec(long jarg1, long jarg2, String jarg3, int jarg4);
  public final static native long zx_locate_ns_by_prefix(long jarg1, int jarg2, String jarg3);
  public final static native int zx_is_ns_prefix(long jarg1, int jarg2, String jarg3);
  public final static native long zx_prefix_seen(long jarg1, int jarg2, String jarg3);
  public final static native long zx_prefix_seen_whine(long jarg1, int jarg2, String jarg3, String jarg4, int jarg5);
  public final static native long zx_scan_xmlns(long jarg1);
  public final static native void zx_pop_seen(long jarg1);
  public final static native String zx_raw_cipher(long jarg1, String jarg2, int jarg3, String jarg4, int jarg5, int jarg7, String jarg8);
  public final static native String zx_rsa_pub_enc(long jarg1, String jarg2, long jarg3, int jarg4);
  public final static native String zx_rsa_pub_dec(long jarg1, String jarg2, long jarg3, int jarg4);
  public final static native String zx_rsa_priv_dec(long jarg1, String jarg2, long jarg3, int jarg4);
  public final static native String zx_rsa_priv_enc(long jarg1, String jarg2, long jarg3, int jarg4);
  public final static native long zx_get_rsa_pub_from_cert(long jarg1, String jarg2);
  public final static native void zx_rand(String jarg1, int jarg2);
  public final static native String zx_md5_crypt(String jarg1, String jarg2, String jarg3);
  public final static native long zx_tok_by_ns(long jarg1, long jarg2, int jarg3, String jarg4, long jarg5);
  public final static native int zx_len_xmlns_if_not_seen(long jarg1, long jarg2, long jarg3);
  public final static native String zx_enc_xmlns_if_not_seen(long jarg1, String jarg2, long jarg3, long jarg4);
  public final static native void zx_add_xmlns_if_not_seen(long jarg1, long jarg2, long jarg3);
  public final static native String zx_enc_seen(String jarg1, long jarg2);
  public final static native int zx_len_so_common(long jarg1, long jarg2);
  public final static native int zx_len_wo_common(long jarg1, long jarg2);
  public final static native String zx_enc_unknown_attrs(String jarg1, long jarg2);
  public final static native String zx_enc_so_unknown_elems_and_content(long jarg1, String jarg2, long jarg3);
  public final static native String zx_easy_enc_common(long jarg1, String jarg2, String jarg3, int jarg4);
  public final static native int zx_attr_so_len(String jarg1, int jarg2);
  public final static native String zx_attr_so_enc(String jarg1, String jarg2, String jarg3, int jarg4);
  public final static native int zx_attr_wo_len(String jarg1, int jarg2);
  public final static native String zx_attr_wo_enc(String jarg1, String jarg2, String jarg3, int jarg4);
  public final static native void zx_free_attr(long jarg1, String jarg2, int jarg3);
  public final static native void zx_free_elem_common(long jarg1, long jarg2, int jarg3);
  public final static native void zx_free_simple_elems(long jarg1, long jarg2, int jarg3);
  public final static native void zx_prepare_dec_ctx(long jarg1, long jarg2, String jarg3, String jarg4);
  public final static native int zx_scan_data(long jarg1, long jarg2);
  public final static native int zx_scan_pi_or_comment(long jarg1);
  public final static native String zx_dec_unknown_attr(long jarg1, long jarg2, String jarg3, String jarg4, int jarg5, int jarg6);
  public final static native String zx_dec_attr_val(long jarg1, long jarg2);
  public final static native void zx_xml_parse_err(long jarg1, char jarg2, String jarg3, String jarg4);
  public final static native int zx_len_inc_ns(long jarg1, long jarg2);
  public final static native void zx_add_inc_ns(long jarg1, long jarg2);
  public final static native String zx_enc_inc_ns(long jarg1, String jarg2, long jarg3);
  public final static native String SIG_ALGO_RSA_SHA1_get();
  public final static native String SIG_ALGO_DSA_SHA1_get();
  public final static native String SIG_ALGO_get();
  public final static native String DIGEST_ALGO_get();
  public final static native String CANON_ALGO_get();
  public final static native String ENVELOPED_ALGO_get();
  public final static native String ENC_ALGO_TRIPLEDES_CBC_get();
  public final static native String ENC_ALGO_AES128_CBC_get();
  public final static native String ENC_ALGO_AES192_CBC_get();
  public final static native String ENC_ALGO_AES256_CBC_get();
  public final static native String ENC_ALGO_get();
  public final static native String ENC_KEYTRAN_RSA_1_5_get();
  public final static native String ENC_KEYTRAN_RSA_OAEP_get();
  public final static native String ENC_KEYTRAN_ALGO_get();
  public final static native String ENC_ENCKEY_METH_get();
  public final static native String ENC_TYPE_ELEMENT_get();
  public final static native String ENC_TYPE_CONTENT_get();
  public final static native int ZXID_CONF_MAGIC_get();
  public final static native int ZXID_CGI_MAGIC_get();
  public final static native int ZXID_SES_MAGIC_get();
  public final static native void zxid_conf_magic_set(long jarg1, long jarg2);
  public final static native long zxid_conf_magic_get(long jarg1);
  public final static native void zxid_conf_ctx_set(long jarg1, long jarg2);
  public final static native long zxid_conf_ctx_get(long jarg1);
  public final static native void zxid_conf_cot_set(long jarg1, long jarg2);
  public final static native long zxid_conf_cot_get(long jarg1);
  public final static native void zxid_conf_path_supplied_set(long jarg1, int jarg2);
  public final static native int zxid_conf_path_supplied_get(long jarg1);
  public final static native void zxid_conf_path_len_set(long jarg1, int jarg2);
  public final static native int zxid_conf_path_len_get(long jarg1);
  public final static native void zxid_conf_path_set(long jarg1, String jarg2);
  public final static native String zxid_conf_path_get(long jarg1);
  public final static native void zxid_conf_url_set(long jarg1, String jarg2);
  public final static native String zxid_conf_url_get(long jarg1);
  public final static native void zxid_conf_non_standard_entityid_set(long jarg1, String jarg2);
  public final static native String zxid_conf_non_standard_entityid_get(long jarg1);
  public final static native void zxid_conf_redirect_hack_imposed_url_set(long jarg1, String jarg2);
  public final static native String zxid_conf_redirect_hack_imposed_url_get(long jarg1);
  public final static native void zxid_conf_redirect_hack_zxid_url_set(long jarg1, String jarg2);
  public final static native String zxid_conf_redirect_hack_zxid_url_get(long jarg1);
  public final static native void zxid_conf_redirect_hack_zxid_qs_set(long jarg1, String jarg2);
  public final static native String zxid_conf_redirect_hack_zxid_qs_get(long jarg1);
  public final static native void zxid_conf_cdc_url_set(long jarg1, String jarg2);
  public final static native String zxid_conf_cdc_url_get(long jarg1);
  public final static native void zxid_conf_cdc_choice_set(long jarg1, char jarg2);
  public final static native char zxid_conf_cdc_choice_get(long jarg1);
  public final static native void zxid_conf_md_fetch_set(long jarg1, char jarg2);
  public final static native char zxid_conf_md_fetch_get(long jarg1);
  public final static native void zxid_conf_md_populate_cache_set(long jarg1, char jarg2);
  public final static native char zxid_conf_md_populate_cache_get(long jarg1);
  public final static native void zxid_conf_md_cache_first_set(long jarg1, char jarg2);
  public final static native char zxid_conf_md_cache_first_get(long jarg1);
  public final static native void zxid_conf_md_cache_last_set(long jarg1, char jarg2);
  public final static native char zxid_conf_md_cache_last_get(long jarg1);
  public final static native void zxid_conf_auto_cert_set(long jarg1, char jarg2);
  public final static native char zxid_conf_auto_cert_get(long jarg1);
  public final static native void zxid_conf_user_local_set(long jarg1, char jarg2);
  public final static native char zxid_conf_user_local_get(long jarg1);
  public final static native void zxid_conf_idp_ena_set(long jarg1, char jarg2);
  public final static native char zxid_conf_idp_ena_get(long jarg1);
  public final static native void zxid_conf_pdp_ena_set(long jarg1, char jarg2);
  public final static native char zxid_conf_pdp_ena_get(long jarg1);
  public final static native void zxid_conf_authn_req_sign_set(long jarg1, char jarg2);
  public final static native char zxid_conf_authn_req_sign_get(long jarg1);
  public final static native void zxid_conf_want_authn_req_signed_set(long jarg1, char jarg2);
  public final static native char zxid_conf_want_authn_req_signed_get(long jarg1);
  public final static native void zxid_conf_want_sso_a7n_signed_set(long jarg1, char jarg2);
  public final static native char zxid_conf_want_sso_a7n_signed_get(long jarg1);
  public final static native void zxid_conf_sso_soap_sign_set(long jarg1, char jarg2);
  public final static native char zxid_conf_sso_soap_sign_get(long jarg1);
  public final static native void zxid_conf_sso_soap_resp_sign_set(long jarg1, char jarg2);
  public final static native char zxid_conf_sso_soap_resp_sign_get(long jarg1);
  public final static native void zxid_conf_sso_sign_set(long jarg1, char jarg2);
  public final static native char zxid_conf_sso_sign_get(long jarg1);
  public final static native void zxid_conf_wsc_sign_set(long jarg1, char jarg2);
  public final static native char zxid_conf_wsc_sign_get(long jarg1);
  public final static native void zxid_conf_wsp_sign_set(long jarg1, char jarg2);
  public final static native char zxid_conf_wsp_sign_get(long jarg1);
  public final static native void zxid_conf_nameid_enc_set(long jarg1, char jarg2);
  public final static native char zxid_conf_nameid_enc_get(long jarg1);
  public final static native void zxid_conf_post_a7n_enc_set(long jarg1, char jarg2);
  public final static native char zxid_conf_post_a7n_enc_get(long jarg1);
  public final static native void zxid_conf_di_allow_create_set(long jarg1, char jarg2);
  public final static native char zxid_conf_di_allow_create_get(long jarg1);
  public final static native void zxid_conf_di_nid_fmt_set(long jarg1, char jarg2);
  public final static native char zxid_conf_di_nid_fmt_get(long jarg1);
  public final static native void zxid_conf_di_a7n_enc_set(long jarg1, char jarg2);
  public final static native char zxid_conf_di_a7n_enc_get(long jarg1);
  public final static native void zxid_conf_show_conf_set(long jarg1, char jarg2);
  public final static native char zxid_conf_show_conf_get(long jarg1);
  public final static native void zxid_conf_affiliation_set(long jarg1, String jarg2);
  public final static native String zxid_conf_affiliation_get(long jarg1);
  public final static native void zxid_conf_nice_name_set(long jarg1, String jarg2);
  public final static native String zxid_conf_nice_name_get(long jarg1);
  public final static native void zxid_conf_ses_arch_dir_set(long jarg1, String jarg2);
  public final static native String zxid_conf_ses_arch_dir_get(long jarg1);
  public final static native void zxid_conf_ses_cookie_name_set(long jarg1, String jarg2);
  public final static native String zxid_conf_ses_cookie_name_get(long jarg1);
  public final static native void zxid_conf_ipport_set(long jarg1, String jarg2);
  public final static native String zxid_conf_ipport_get(long jarg1);
  public final static native void zxid_conf_log_err_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_err_get(long jarg1);
  public final static native void zxid_conf_log_act_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_act_get(long jarg1);
  public final static native void zxid_conf_log_issue_a7n_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_issue_a7n_get(long jarg1);
  public final static native void zxid_conf_log_issue_msg_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_issue_msg_get(long jarg1);
  public final static native void zxid_conf_log_rely_a7n_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_rely_a7n_get(long jarg1);
  public final static native void zxid_conf_log_rely_msg_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_rely_msg_get(long jarg1);
  public final static native void zxid_conf_log_err_in_act_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_err_in_act_get(long jarg1);
  public final static native void zxid_conf_log_act_in_err_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_act_in_err_get(long jarg1);
  public final static native void zxid_conf_log_sigfail_is_err_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_sigfail_is_err_get(long jarg1);
  public final static native void zxid_conf_log_level_set(long jarg1, char jarg2);
  public final static native char zxid_conf_log_level_get(long jarg1);
  public final static native void zxid_conf_sig_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_sig_fatal_get(long jarg1);
  public final static native void zxid_conf_nosig_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_nosig_fatal_get(long jarg1);
  public final static native void zxid_conf_msg_sig_ok_set(long jarg1, char jarg2);
  public final static native char zxid_conf_msg_sig_ok_get(long jarg1);
  public final static native void zxid_conf_timeout_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_timeout_fatal_get(long jarg1);
  public final static native void zxid_conf_audience_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_audience_fatal_get(long jarg1);
  public final static native void zxid_conf_dup_a7n_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_dup_a7n_fatal_get(long jarg1);
  public final static native void zxid_conf_dup_msg_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_dup_msg_fatal_get(long jarg1);
  public final static native void zxid_conf_wsp_nosig_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_wsp_nosig_fatal_get(long jarg1);
  public final static native void zxid_conf_notimestamp_fatal_set(long jarg1, char jarg2);
  public final static native char zxid_conf_notimestamp_fatal_get(long jarg1);
  public final static native void zxid_conf_redir_to_content_set(long jarg1, char jarg2);
  public final static native char zxid_conf_redir_to_content_get(long jarg1);
  public final static native void zxid_conf_remote_user_ena_set(long jarg1, char jarg2);
  public final static native char zxid_conf_remote_user_ena_get(long jarg1);
  public final static native void zxid_conf_anon_ok_set(long jarg1, String jarg2);
  public final static native String zxid_conf_anon_ok_get(long jarg1);
  public final static native void zxid_conf_required_authnctx_set(long jarg1, long jarg2);
  public final static native long zxid_conf_required_authnctx_get(long jarg1);
  public final static native void zxid_conf_issue_authnctx_pw_set(long jarg1, String jarg2);
  public final static native String zxid_conf_issue_authnctx_pw_get(long jarg1);
  public final static native void zxid_conf_idp_pref_acs_binding_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_pref_acs_binding_get(long jarg1);
  public final static native void zxid_conf_before_slop_set(long jarg1, int jarg2);
  public final static native int zxid_conf_before_slop_get(long jarg1);
  public final static native void zxid_conf_after_slop_set(long jarg1, int jarg2);
  public final static native int zxid_conf_after_slop_get(long jarg1);
  public final static native void zxid_conf_timeskew_set(long jarg1, int jarg2);
  public final static native int zxid_conf_timeskew_get(long jarg1);
  public final static native void zxid_conf_a7nttl_set(long jarg1, int jarg2);
  public final static native int zxid_conf_a7nttl_get(long jarg1);
  public final static native void zxid_conf_pdp_url_set(long jarg1, String jarg2);
  public final static native String zxid_conf_pdp_url_get(long jarg1);
  public final static native void zxid_conf_pdp_call_url_set(long jarg1, String jarg2);
  public final static native String zxid_conf_pdp_call_url_get(long jarg1);
  public final static native void zxid_conf_xasp_vers_set(long jarg1, String jarg2);
  public final static native String zxid_conf_xasp_vers_get(long jarg1);
  public final static native void zxid_conf_need_set(long jarg1, long jarg2);
  public final static native long zxid_conf_need_get(long jarg1);
  public final static native void zxid_conf_want_set(long jarg1, long jarg2);
  public final static native long zxid_conf_want_get(long jarg1);
  public final static native void zxid_conf_attrsrc_set(long jarg1, long jarg2);
  public final static native long zxid_conf_attrsrc_get(long jarg1);
  public final static native void zxid_conf_inmap_set(long jarg1, long jarg2);
  public final static native long zxid_conf_inmap_get(long jarg1);
  public final static native void zxid_conf_outmap_set(long jarg1, long jarg2);
  public final static native long zxid_conf_outmap_get(long jarg1);
  public final static native void zxid_conf_pepmap_set(long jarg1, long jarg2);
  public final static native long zxid_conf_pepmap_get(long jarg1);
  public final static native void zxid_conf_localpdp_role_permit_set(long jarg1, long jarg2);
  public final static native long zxid_conf_localpdp_role_permit_get(long jarg1);
  public final static native void zxid_conf_localpdp_role_deny_set(long jarg1, long jarg2);
  public final static native long zxid_conf_localpdp_role_deny_get(long jarg1);
  public final static native void zxid_conf_localpdp_idpnid_permit_set(long jarg1, long jarg2);
  public final static native long zxid_conf_localpdp_idpnid_permit_get(long jarg1);
  public final static native void zxid_conf_localpdp_idpnid_deny_set(long jarg1, long jarg2);
  public final static native long zxid_conf_localpdp_idpnid_deny_get(long jarg1);
  public final static native void zxid_conf_max_soap_retry_set(long jarg1, int jarg2);
  public final static native int zxid_conf_max_soap_retry_get(long jarg1);
  public final static native void zxid_conf_defaultqs_set(long jarg1, String jarg2);
  public final static native String zxid_conf_defaultqs_get(long jarg1);
  public final static native void zxid_conf_mod_saml_attr_prefix_set(long jarg1, String jarg2);
  public final static native String zxid_conf_mod_saml_attr_prefix_get(long jarg1);
  public final static native void zxid_conf_idp_sel_page_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_page_get(long jarg1);
  public final static native void zxid_conf_idp_sel_start_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_start_get(long jarg1);
  public final static native void zxid_conf_idp_sel_new_idp_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_new_idp_get(long jarg1);
  public final static native void zxid_conf_idp_sel_our_eid_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_our_eid_get(long jarg1);
  public final static native void zxid_conf_idp_sel_tech_user_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_tech_user_get(long jarg1);
  public final static native void zxid_conf_idp_sel_tech_site_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_tech_site_get(long jarg1);
  public final static native void zxid_conf_idp_sel_footer_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_footer_get(long jarg1);
  public final static native void zxid_conf_idp_sel_end_set(long jarg1, String jarg2);
  public final static native String zxid_conf_idp_sel_end_get(long jarg1);
  public final static native void zxid_conf_an_page_set(long jarg1, String jarg2);
  public final static native String zxid_conf_an_page_get(long jarg1);
  public final static native void zxid_conf_an_start_set(long jarg1, String jarg2);
  public final static native String zxid_conf_an_start_get(long jarg1);
  public final static native void zxid_conf_an_our_eid_set(long jarg1, String jarg2);
  public final static native String zxid_conf_an_our_eid_get(long jarg1);
  public final static native void zxid_conf_an_tech_user_set(long jarg1, String jarg2);
  public final static native String zxid_conf_an_tech_user_get(long jarg1);
  public final static native void zxid_conf_an_tech_site_set(long jarg1, String jarg2);
  public final static native String zxid_conf_an_tech_site_get(long jarg1);
  public final static native void zxid_conf_an_footer_set(long jarg1, String jarg2);
  public final static native String zxid_conf_an_footer_get(long jarg1);
  public final static native void zxid_conf_an_end_set(long jarg1, String jarg2);
  public final static native String zxid_conf_an_end_get(long jarg1);
  public final static native void zxid_conf_mgmt_start_set(long jarg1, String jarg2);
  public final static native String zxid_conf_mgmt_start_get(long jarg1);
  public final static native void zxid_conf_mgmt_logout_set(long jarg1, String jarg2);
  public final static native String zxid_conf_mgmt_logout_get(long jarg1);
  public final static native void zxid_conf_mgmt_defed_set(long jarg1, String jarg2);
  public final static native String zxid_conf_mgmt_defed_get(long jarg1);
  public final static native void zxid_conf_mgmt_footer_set(long jarg1, String jarg2);
  public final static native String zxid_conf_mgmt_footer_get(long jarg1);
  public final static native void zxid_conf_mgmt_end_set(long jarg1, String jarg2);
  public final static native String zxid_conf_mgmt_end_get(long jarg1);
  public final static native void zxid_conf_dbg_set(long jarg1, String jarg2);
  public final static native String zxid_conf_dbg_get(long jarg1);
  public final static native long new_zxid_conf();
  public final static native void delete_zxid_conf(long jarg1);
  public final static native void zxid_cgi_magic_set(long jarg1, long jarg2);
  public final static native long zxid_cgi_magic_get(long jarg1);
  public final static native void zxid_cgi_op_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_op_get(long jarg1);
  public final static native void zxid_cgi_pr_ix_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_pr_ix_get(long jarg1);
  public final static native void zxid_cgi_allow_create_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_allow_create_get(long jarg1);
  public final static native void zxid_cgi_ispassive_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_ispassive_get(long jarg1);
  public final static native void zxid_cgi_force_authn_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_force_authn_get(long jarg1);
  public final static native void zxid_cgi_enc_hint_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_enc_hint_get(long jarg1);
  public final static native void zxid_cgi_pad6_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_pad6_get(long jarg1);
  public final static native void zxid_cgi_pad7_set(long jarg1, char jarg2);
  public final static native char zxid_cgi_pad7_get(long jarg1);
  public final static native void zxid_cgi_sid_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_sid_get(long jarg1);
  public final static native void zxid_cgi_nid_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_nid_get(long jarg1);
  public final static native void zxid_cgi_uid_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_uid_get(long jarg1);
  public final static native void zxid_cgi_pw_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_pw_get(long jarg1);
  public final static native void zxid_cgi_ssoreq_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_ssoreq_get(long jarg1);
  public final static native void zxid_cgi_cdc_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_cdc_get(long jarg1);
  public final static native void zxid_cgi_eid_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_eid_get(long jarg1);
  public final static native void zxid_cgi_nid_fmt_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_nid_fmt_get(long jarg1);
  public final static native void zxid_cgi_affil_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_affil_get(long jarg1);
  public final static native void zxid_cgi_consent_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_consent_get(long jarg1);
  public final static native void zxid_cgi_matching_rule_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_matching_rule_get(long jarg1);
  public final static native void zxid_cgi_authn_ctx_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_authn_ctx_get(long jarg1);
  public final static native void zxid_cgi_pxy_count_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_pxy_count_get(long jarg1);
  public final static native void zxid_cgi_get_complete_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_get_complete_get(long jarg1);
  public final static native void zxid_cgi_idppxylist_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_idppxylist_get(long jarg1);
  public final static native void zxid_cgi_rs_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_rs_get(long jarg1);
  public final static native void zxid_cgi_newnym_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_newnym_get(long jarg1);
  public final static native void zxid_cgi_saml_art_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_saml_art_get(long jarg1);
  public final static native void zxid_cgi_saml_resp_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_saml_resp_get(long jarg1);
  public final static native void zxid_cgi_saml_req_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_saml_req_get(long jarg1);
  public final static native void zxid_cgi_sigalg_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_sigalg_get(long jarg1);
  public final static native void zxid_cgi_sig_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_sig_get(long jarg1);
  public final static native void zxid_cgi_sigval_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_sigval_get(long jarg1);
  public final static native void zxid_cgi_sigmsg_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_sigmsg_get(long jarg1);
  public final static native void zxid_cgi_err_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_err_get(long jarg1);
  public final static native void zxid_cgi_msg_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_msg_get(long jarg1);
  public final static native void zxid_cgi_dbg_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_dbg_get(long jarg1);
  public final static native void zxid_cgi_zxapp_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_zxapp_get(long jarg1);
  public final static native void zxid_cgi_zxrfr_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_zxrfr_get(long jarg1);
  public final static native void zxid_cgi_ok_set(long jarg1, String jarg2);
  public final static native String zxid_cgi_ok_get(long jarg1);
  public final static native void zxid_cgi_idp_list_set(long jarg1, long jarg2);
  public final static native long zxid_cgi_idp_list_get(long jarg1);
  public final static native long new_zxid_cgi();
  public final static native void delete_zxid_cgi(long jarg1);
  public final static native void zxid_ses_magic_set(long jarg1, long jarg2);
  public final static native long zxid_ses_magic_get(long jarg1);
  public final static native void zxid_ses_sid_set(long jarg1, String jarg2);
  public final static native String zxid_ses_sid_get(long jarg1);
  public final static native void zxid_ses_uid_set(long jarg1, String jarg2);
  public final static native String zxid_ses_uid_get(long jarg1);
  public final static native void zxid_ses_nid_set(long jarg1, String jarg2);
  public final static native String zxid_ses_nid_get(long jarg1);
  public final static native void zxid_ses_tgt_set(long jarg1, String jarg2);
  public final static native String zxid_ses_tgt_get(long jarg1);
  public final static native void zxid_ses_sesix_set(long jarg1, String jarg2);
  public final static native String zxid_ses_sesix_get(long jarg1);
  public final static native void zxid_ses_msgid_set(long jarg1, String jarg2);
  public final static native String zxid_ses_msgid_get(long jarg1);
  public final static native void zxid_ses_an_ctx_set(long jarg1, String jarg2);
  public final static native String zxid_ses_an_ctx_get(long jarg1);
  public final static native void zxid_ses_nidfmt_set(long jarg1, char jarg2);
  public final static native char zxid_ses_nidfmt_get(long jarg1);
  public final static native void zxid_ses_tgtfmt_set(long jarg1, char jarg2);
  public final static native char zxid_ses_tgtfmt_get(long jarg1);
  public final static native void zxid_ses_sigres_set(long jarg1, char jarg2);
  public final static native char zxid_ses_sigres_get(long jarg1);
  public final static native void zxid_ses_pad3_set(long jarg1, char jarg2);
  public final static native char zxid_ses_pad3_get(long jarg1);
  public final static native void zxid_ses_sso_a7n_path_set(long jarg1, String jarg2);
  public final static native String zxid_ses_sso_a7n_path_get(long jarg1);
  public final static native void zxid_ses_tgt_a7n_path_set(long jarg1, String jarg2);
  public final static native String zxid_ses_tgt_a7n_path_get(long jarg1);
  public final static native void zxid_ses_setcookie_set(long jarg1, String jarg2);
  public final static native String zxid_ses_setcookie_get(long jarg1);
  public final static native void zxid_ses_cookie_set(long jarg1, String jarg2);
  public final static native String zxid_ses_cookie_get(long jarg1);
  public final static native void zxid_ses_rs_set(long jarg1, String jarg2);
  public final static native String zxid_ses_rs_get(long jarg1);
  public final static native void zxid_ses_nameid_set(long jarg1, long jarg2);
  public final static native long zxid_ses_nameid_get(long jarg1);
  public final static native void zxid_ses_a7n_set(long jarg1, long jarg2);
  public final static native long zxid_ses_a7n_get(long jarg1);
  public final static native void zxid_ses_tgta7n_set(long jarg1, long jarg2);
  public final static native long zxid_ses_tgta7n_get(long jarg1);
  public final static native void zxid_ses_a7n11_set(long jarg1, long jarg2);
  public final static native long zxid_ses_a7n11_get(long jarg1);
  public final static native void zxid_ses_tgta7n11_set(long jarg1, long jarg2);
  public final static native long zxid_ses_tgta7n11_get(long jarg1);
  public final static native void zxid_ses_a7n12_set(long jarg1, long jarg2);
  public final static native long zxid_ses_a7n12_get(long jarg1);
  public final static native void zxid_ses_tgta7n12_set(long jarg1, long jarg2);
  public final static native long zxid_ses_tgta7n12_get(long jarg1);
  public final static native void zxid_ses_sesbuf_set(long jarg1, String jarg2);
  public final static native String zxid_ses_sesbuf_get(long jarg1);
  public final static native void zxid_ses_sso_a7n_buf_set(long jarg1, String jarg2);
  public final static native String zxid_ses_sso_a7n_buf_get(long jarg1);
  public final static native void zxid_ses_at_set(long jarg1, long jarg2);
  public final static native long zxid_ses_at_get(long jarg1);
  public final static native long new_zxid_ses();
  public final static native void delete_zxid_ses(long jarg1);
  public final static native void zxid_attr_n_set(long jarg1, long jarg2);
  public final static native long zxid_attr_n_get(long jarg1);
  public final static native void zxid_attr_nv_set(long jarg1, long jarg2);
  public final static native long zxid_attr_nv_get(long jarg1);
  public final static native void zxid_attr_name_set(long jarg1, String jarg2);
  public final static native String zxid_attr_name_get(long jarg1);
  public final static native void zxid_attr_val_set(long jarg1, String jarg2);
  public final static native String zxid_attr_val_get(long jarg1);
  public final static native void zxid_attr_map_val_set(long jarg1, String jarg2);
  public final static native String zxid_attr_map_val_get(long jarg1);
  public final static native void zxid_attr_orig_set(long jarg1, long jarg2);
  public final static native long zxid_attr_orig_get(long jarg1);
  public final static native void zxid_attr_issuer_set(long jarg1, String jarg2);
  public final static native String zxid_attr_issuer_get(long jarg1);
  public final static native long new_zxid_attr();
  public final static native void delete_zxid_attr(long jarg1);
  public final static native void zxid_need_n_set(long jarg1, long jarg2);
  public final static native long zxid_need_n_get(long jarg1);
  public final static native void zxid_need_at_set(long jarg1, long jarg2);
  public final static native long zxid_need_at_get(long jarg1);
  public final static native void zxid_need_usage_set(long jarg1, String jarg2);
  public final static native String zxid_need_usage_get(long jarg1);
  public final static native void zxid_need_retent_set(long jarg1, String jarg2);
  public final static native String zxid_need_retent_get(long jarg1);
  public final static native void zxid_need_oblig_set(long jarg1, String jarg2);
  public final static native String zxid_need_oblig_get(long jarg1);
  public final static native void zxid_need_ext_set(long jarg1, String jarg2);
  public final static native String zxid_need_ext_get(long jarg1);
  public final static native long new_zxid_need();
  public final static native void delete_zxid_need(long jarg1);
  public final static native void zxid_map_n_set(long jarg1, long jarg2);
  public final static native long zxid_map_n_get(long jarg1);
  public final static native void zxid_map_rule_set(long jarg1, int jarg2);
  public final static native int zxid_map_rule_get(long jarg1);
  public final static native void zxid_map_ns_set(long jarg1, String jarg2);
  public final static native String zxid_map_ns_get(long jarg1);
  public final static native void zxid_map_src_set(long jarg1, String jarg2);
  public final static native String zxid_map_src_get(long jarg1);
  public final static native void zxid_map_dst_set(long jarg1, String jarg2);
  public final static native String zxid_map_dst_get(long jarg1);
  public final static native void zxid_map_ext_set(long jarg1, String jarg2);
  public final static native String zxid_map_ext_get(long jarg1);
  public final static native long new_zxid_map();
  public final static native void delete_zxid_map(long jarg1);
  public final static native void zxid_cstr_list_n_set(long jarg1, long jarg2);
  public final static native long zxid_cstr_list_n_get(long jarg1);
  public final static native void zxid_cstr_list_s_set(long jarg1, String jarg2);
  public final static native String zxid_cstr_list_s_get(long jarg1);
  public final static native long new_zxid_cstr_list();
  public final static native void delete_zxid_cstr_list(long jarg1);
  public final static native int ZXID_MAP_RULE_RENAME_get();
  public final static native int ZXID_MAP_RULE_DEL_get();
  public final static native int ZXID_MAP_RULE_RESET_get();
  public final static native int ZXID_MAP_RULE_FEIDEDEC_get();
  public final static native int ZXID_MAP_RULE_FEIDEENC_get();
  public final static native int ZXID_MAP_RULE_UNSB64_INF_get();
  public final static native int ZXID_MAP_RULE_DEF_SB64_get();
  public final static native int ZXID_MAP_RULE_UNSB64_get();
  public final static native int ZXID_MAP_RULE_SB64_get();
  public final static native void zxid_atsrc_n_set(long jarg1, long jarg2);
  public final static native long zxid_atsrc_n_get(long jarg1);
  public final static native void zxid_atsrc_at_set(long jarg1, long jarg2);
  public final static native long zxid_atsrc_at_get(long jarg1);
  public final static native void zxid_atsrc_ns_set(long jarg1, String jarg2);
  public final static native String zxid_atsrc_ns_get(long jarg1);
  public final static native void zxid_atsrc_weight_set(long jarg1, String jarg2);
  public final static native String zxid_atsrc_weight_get(long jarg1);
  public final static native void zxid_atsrc_url_set(long jarg1, String jarg2);
  public final static native String zxid_atsrc_url_get(long jarg1);
  public final static native void zxid_atsrc_aapml_set(long jarg1, String jarg2);
  public final static native String zxid_atsrc_aapml_get(long jarg1);
  public final static native void zxid_atsrc_otherlim_set(long jarg1, String jarg2);
  public final static native String zxid_atsrc_otherlim_get(long jarg1);
  public final static native void zxid_atsrc_ext_set(long jarg1, String jarg2);
  public final static native String zxid_atsrc_ext_get(long jarg1);
  public final static native long new_zxid_atsrc();
  public final static native void delete_zxid_atsrc(long jarg1);
  public final static native String ZXID_SES_DIR_get();
  public final static native String ZXID_USER_DIR_get();
  public final static native String ZXID_UID_DIR_get();
  public final static native String ZXID_NID_DIR_get();
  public final static native String ZXID_PEM_DIR_get();
  public final static native String ZXID_COT_DIR_get();
  public final static native String ZXID_DIMD_DIR_get();
  public final static native int ZXID_MAX_USER_get();
  public final static native int ZXID_MAX_MD_get();
  public final static native int ZXID_MAX_SOAP_get();
  public final static native int ZXID_MAX_EID_get();
  public final static native int ZXID_MAX_DIR_get();
  public final static native void zxid_entity_n_set(long jarg1, long jarg2);
  public final static native long zxid_entity_n_get(long jarg1);
  public final static native void zxid_entity_n_cdc_set(long jarg1, long jarg2);
  public final static native long zxid_entity_n_cdc_get(long jarg1);
  public final static native void zxid_entity_eid_len_set(long jarg1, int jarg2);
  public final static native int zxid_entity_eid_len_get(long jarg1);
  public final static native void zxid_entity_eid_set(long jarg1, String jarg2);
  public final static native String zxid_entity_eid_get(long jarg1);
  public final static native void zxid_entity_sha1_name_set(long jarg1, String jarg2);
  public final static native String zxid_entity_sha1_name_get(long jarg1);
  public final static native void zxid_entity_tls_cert_set(long jarg1, long jarg2);
  public final static native long zxid_entity_tls_cert_get(long jarg1);
  public final static native void zxid_entity_sign_cert_set(long jarg1, long jarg2);
  public final static native long zxid_entity_sign_cert_get(long jarg1);
  public final static native void zxid_entity_enc_cert_set(long jarg1, long jarg2);
  public final static native long zxid_entity_enc_cert_get(long jarg1);
  public final static native void zxid_entity_ed_set(long jarg1, long jarg2);
  public final static native long zxid_entity_ed_get(long jarg1);
  public final static native long new_zxid_entity();
  public final static native void delete_zxid_entity(long jarg1);
  public final static native int ZXID_AUTO_EXIT_get();
  public final static native int ZXID_AUTO_REDIR_get();
  public final static native int ZXID_AUTO_SOAPC_get();
  public final static native int ZXID_AUTO_SOAPH_get();
  public final static native int ZXID_AUTO_METAC_get();
  public final static native int ZXID_AUTO_METAH_get();
  public final static native int ZXID_AUTO_LOGINC_get();
  public final static native int ZXID_AUTO_LOGINH_get();
  public final static native int ZXID_AUTO_MGMTC_get();
  public final static native int ZXID_AUTO_MGMTH_get();
  public final static native int ZXID_AUTO_FORMF_get();
  public final static native int ZXID_AUTO_FORMT_get();
  public final static native int ZXID_AUTO_ALL_get();
  public final static native int ZXID_AUTO_DEBUG_get();
  public final static native int ZXID_AUTO_FMTQ_get();
  public final static native int ZXID_AUTO_FMTJ_get();
  public final static native String zxid_simple(String jarg1, String jarg2, int jarg3);
  public final static native String zxid_idp_list(String jarg1, int jarg2);
  public final static native String zxid_idp_select(String jarg1, int jarg2);
  public final static native String zxid_fed_mgmt(String jarg1, String jarg2, int jarg3);
  public final static native long zxid_new_conf_to_cf(String jarg1);
  public final static native String zxid_simple_cf(long jarg1, int jarg2, String jarg3, long jarg4, int jarg5);
  public final static native String zxid_idp_list_cf(long jarg1, long jarg2, int jarg3);
  public final static native String zxid_idp_select_cf(long jarg1, long jarg2, int jarg3);
  public final static native String zxid_fed_mgmt_cf(long jarg1, long jarg2, int jarg3, String jarg4, int jarg5);
  public final static native int zxid_conf_to_cf_len(long jarg1, int jarg2, String jarg3);
  public final static native String zxid_simple_len(int jarg1, String jarg2, int jarg3, String jarg4, long jarg5, int jarg6);
  public final static native String zxid_idp_list_len(int jarg1, String jarg2, long jarg3, int jarg4);
  public final static native String zxid_idp_select_len(int jarg1, String jarg2, long jarg3, int jarg4);
  public final static native String zxid_fed_mgmt_len(int jarg1, String jarg2, long jarg3, String jarg4, int jarg5);
  public final static native String zxid_idp_select_zxstr_cf(long jarg1, int jarg2);
  public final static native String zxid_simple_ab_pep(long jarg1, long jarg2, long jarg3, int jarg4);
  public final static native String zxid_simple_ses_active_cf(long jarg1, long jarg2, long jarg3, long jarg4, int jarg5);
  public final static native String zxid_simple_no_ses_cf(long jarg1, long jarg2, long jarg3, long jarg4, int jarg5);
  public final static native int ZXID_SSO_SIGN_A7N_get();
  public final static native int ZXID_SSO_SIGN_RESP_get();
  public final static native int ZXID_SSO_SIGN_A7N_SIMPLE_get();
  public final static native int ZXID_SIGN_HDR_get();
  public final static native int ZXID_SIGN_BDY_get();
  public final static native void zxsig_ref_sref_set(long jarg1, long jarg2);
  public final static native long zxsig_ref_sref_get(long jarg1);
  public final static native void zxsig_ref_blob_set(long jarg1, long jarg2);
  public final static native long zxsig_ref_blob_get(long jarg1);
  public final static native void zxsig_ref_id_set(long jarg1, String jarg2);
  public final static native String zxsig_ref_id_get(long jarg1);
  public final static native void zxsig_ref_canon_set(long jarg1, String jarg2);
  public final static native String zxsig_ref_canon_get(long jarg1);
  public final static native long new_zxsig_ref();
  public final static native void delete_zxsig_ref(long jarg1);
  public final static native int ZXSIG_OK_get();
  public final static native int ZXSIG_BAD_DALGO_get();
  public final static native int ZXSIG_DIGEST_LEN_get();
  public final static native int ZXSIG_BAD_DIGEST_get();
  public final static native int ZXSIG_BAD_SALGO_get();
  public final static native int ZXSIG_BAD_CERT_get();
  public final static native int ZXSIG_VFY_FAIL_get();
  public final static native int ZXSIG_NO_SIG_get();
  public final static native int ZXSIG_TIMEOUT_get();
  public final static native int ZXSIG_AUDIENCE_get();
  public final static native long zxsig_sign(long jarg1, int jarg2, long jarg3, long jarg4, long jarg5);
  public final static native int zxsig_validate(long jarg1, long jarg2, long jarg3, int jarg4, long jarg5);
  public final static native int zxsig_data_rsa_sha1(long jarg1, int jarg2, String jarg3, long jarg4, long jarg5, String jarg6);
  public final static native int zxsig_verify_data_rsa_sha1(int jarg1, String jarg2, int jarg3, String jarg4, long jarg5, String jarg6);
  public final static native String zxenc_symkey_dec(long jarg1, long jarg2, String jarg3);
  public final static native String zxenc_privkey_dec(long jarg1, long jarg2, long jarg3);
  public final static native long zxenc_symkey_enc(long jarg1, String jarg2, String jarg3, String jarg4, String jarg5);
  public final static native long zxenc_pubkey_enc(long jarg1, String jarg2, long jarg3, long jarg4, String jarg5);
  public final static native String ZXLOG_RELY_DIR_get();
  public final static native String ZXLOG_ISSUE_DIR_get();
  public final static native String ZXLOG_A7N_KIND_get();
  public final static native String ZXLOG_MSG_KIND_get();
  public final static native String ZXLOG_WIR_KIND_get();
  public final static native void zxlog_write_line(long jarg1, String jarg2, int jarg3, int jarg4, String jarg5);
  public final static native String zxlog_path(long jarg1, String jarg2, String jarg3, String jarg4, String jarg5, int jarg6);
  public final static native int zxlog_dup_check(long jarg1, String jarg2, String jarg3);
  public final static native int zxlog_blob(long jarg1, int jarg2, String jarg3, String jarg4, String jarg5);
  public final static native int zxlog(long jarg1, long jarg2, long jarg3, String jarg4, String jarg5, String jarg6, String jarg7, String jarg8, String jarg9, String jarg10, String jarg11, String jarg12, String jarg13);
  public final static native long zxid_get_ent_from_file(long jarg1, String jarg2);
  public final static native long zxid_get_ent_from_cache(long jarg1, String jarg2);
  public final static native int zxid_write_ent_to_cache(long jarg1, long jarg2);
  public final static native long zxid_parse_meta(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_get_meta_ss(long jarg1, String jarg2);
  public final static native long zxid_get_meta(long jarg1, String jarg2);
  public final static native long zxid_get_ent_ss(long jarg1, String jarg2);
  public final static native long zxid_get_ent(long jarg1, String jarg2);
  public final static native long zxid_get_ent_by_succinct_id(long jarg1, String jarg2);
  public final static native long zxid_get_ent_by_sha1_name(long jarg1, String jarg2);
  public final static native long zxid_load_cot_cache(long jarg1);
  public final static native long zxid_key_info(long jarg1, long jarg2);
  public final static native long zxid_key_desc(long jarg1, String jarg2, long jarg3);
  public final static native long zxid_ar_desc(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native long zxid_sso_desc(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native long zxid_slo_desc(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native long zxid_mni_desc(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native long zxid_ac_desc(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native long zxid_idp_sso_desc(long jarg1);
  public final static native long zxid_sp_sso_desc(long jarg1);
  public final static native String zxid_sp_meta(long jarg1, long jarg2);
  public final static native int zxid_send_sp_meta(long jarg1, long jarg2);
  public final static native String zxid_sp_carml(long jarg1);
  public final static native String zxid_my_entity_id(long jarg1);
  public final static native String zxid_my_cdc_url(long jarg1);
  public final static native long zxid_my_issuer(long jarg1);
  public final static native void zxid_sha1_file(long jarg1, String jarg2, String jarg3);
  public final static native long zxid_extract_cert(String jarg1, String jarg2);
  public final static native long zxid_extract_private_key(String jarg1, String jarg2);
  public final static native long zxid_read_cert(long jarg1, String jarg2);
  public final static native long zxid_read_private_key(long jarg1, String jarg2);
  public final static native int zxid_set_opt(long jarg1, int jarg2, int jarg3);
  public final static native String zxid_set_opt_cstr(long jarg1, int jarg2, String jarg3);
  public final static native void zxid_url_set(long jarg1, String jarg2);
  public final static native int zxid_init_conf(long jarg1, String jarg2);
  public final static native long zxid_init_conf_ctx(long jarg1, String jarg2);
  public final static native long zxid_new_conf(String jarg1);
  public final static native int zxid_parse_conf_raw(long jarg1, int jarg2, String jarg3);
  public final static native int zxid_parse_conf(long jarg1, String jarg2);
  public final static native int zxid_mk_self_sig_cert(long jarg1, int jarg2, String jarg3, String jarg4, String jarg5);
  public final static native long zxid_load_map(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_load_need(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_load_atsrc(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_new_at(long jarg1, long jarg2, int jarg3, String jarg4, int jarg5, String jarg6, String jarg7);
  public final static native long zxid_load_cstr_list(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_is_needed(long jarg1, String jarg2);
  public final static native long zxid_find_map(long jarg1, String jarg2);
  public final static native long zxid_find_cstr_list(long jarg1, String jarg2);
  public final static native long zxid_find_at(long jarg1, String jarg2);
  public final static native String zxid_show_conf(long jarg1);
  public final static native int zxid_parse_cgi(long jarg1, String jarg2);
  public final static native long zxid_new_cgi(long jarg1, String jarg2);
  public final static native void zxid_get_sid_from_cookie(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_alloc_ses(long jarg1);
  public final static native long zxid_fetch_ses(long jarg1, String jarg2);
  public final static native int zxid_get_ses(long jarg1, long jarg2, String jarg3);
  public final static native int zxid_put_ses(long jarg1, long jarg2);
  public final static native int zxid_del_ses(long jarg1, long jarg2);
  public final static native int zxid_get_ses_sso_a7n(long jarg1, long jarg2);
  public final static native long zxid_get_ses_idp(long jarg1, long jarg2);
  public final static native int zxid_find_ses(long jarg1, long jarg2, String jarg3, String jarg4);
  public final static native String zxid_pool_to_ldif(long jarg1, long jarg2);
  public final static native String zxid_pool_to_json(long jarg1, long jarg2);
  public final static native String zxid_pool_to_qs(long jarg1, long jarg2);
  public final static native void zxid_ses_to_pool(long jarg1, long jarg2);
  public final static native void zxid_add_attr_to_pool(long jarg1, long jarg2, String jarg3, String jarg4);
  public final static native int zxid_add_qs_to_pool(long jarg1, long jarg2, String jarg3, int jarg4);
  public final static native long zxid_parse_mni(long jarg1, String jarg2, long jarg3);
  public final static native int zxid_put_user(long jarg1, String jarg2, String jarg3, String jarg4, String jarg5, String jarg6);
  public final static native long zxid_get_user_nameid(long jarg1, long jarg2);
  public final static native void zxid_user_change_nameid(long jarg1, long jarg2, String jarg3);
  public final static native int zxid_pw_authn(long jarg1, long jarg2, long jarg3);
  public final static native int zxid_version();
  public final static native String zxid_version_str();
  public final static native String zxid_date_time(long jarg1, long jarg2);
  public final static native String zxid_mk_id(long jarg1, String jarg2, int jarg3);
  public final static native long zxid_soap_call_raw(long jarg1, String jarg2, String jarg3);
  public final static native String zxid_lecp_check(long jarg1, long jarg2);
  public final static native int zxid_cdc_read(long jarg1, long jarg2);
  public final static native int zxid_cdc_check(long jarg1, long jarg2);
  public final static native long zxid_soap_call_envelope(long jarg1, String jarg2, long jarg3);
  public final static native long zxid_soap_call_hdr_body(long jarg1, String jarg2, long jarg3, long jarg4);
  public final static native long zxid_soap_call_body(long jarg1, String jarg2, long jarg3);
  public final static native int zxid_soap_cgi_resp_body(long jarg1, long jarg2);
  public final static native String zxid_saml2_post_enc(long jarg1, String jarg2, String jarg3, String jarg4, int jarg5, String jarg6);
  public final static native String zxid_saml2_redir_enc(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native String zxid_saml2_redir_url(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native String zxid_saml2_redir(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native String zxid_saml2_resp_redir(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native int zxid_saml_ok(long jarg1, long jarg2, long jarg3, String jarg4);
  public final static native long zxid_decrypt_nameid(long jarg1, long jarg2, long jarg3);
  public final static native String zxid_decrypt_newnym(long jarg1, String jarg2, long jarg3);
  public final static native int zxid_chk_sig(long jarg1, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, String jarg7);
  public final static native String zxid_map_val(long jarg1, long jarg2, String jarg3);
  public final static native String zxid_idp_loc_raw(long jarg1, long jarg2, long jarg3, int jarg4, String jarg5, int jarg6);
  public final static native String zxid_idp_loc(long jarg1, long jarg2, long jarg3, long jarg4, int jarg5, String jarg6);
  public final static native long zxid_idp_soap(long jarg1, long jarg2, long jarg3, long jarg4, int jarg5, long jarg6);
  public final static native String zxid_sp_loc_by_index_raw(long jarg1, long jarg2, long jarg3, int jarg4, String jarg5, long jarg6);
  public final static native String zxid_sp_loc_raw(long jarg1, long jarg2, long jarg3, int jarg4, String jarg5, int jarg6);
  public final static native String zxid_sp_loc(long jarg1, long jarg2, long jarg3, long jarg4, int jarg5, String jarg6);
  public final static native long zxid_sp_soap(long jarg1, long jarg2, long jarg3, long jarg4, int jarg5, long jarg6);
  public final static native long zxid_decode_redir_or_post(long jarg1, long jarg2, long jarg3, int jarg4);
  public final static native String zxid_sp_dispatch(long jarg1, long jarg2, long jarg3);
  public final static native int zxid_sp_soap_dispatch(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native int zxid_sp_soap_parse(long jarg1, long jarg2, long jarg3, int jarg4, String jarg5);
  public final static native long zxid_dec_a7n(long jarg1, long jarg2, long jarg3);
  public final static native String zxid_idp_dispatch(long jarg1, long jarg2, long jarg3, int jarg4);
  public final static native int zxid_idp_soap_dispatch(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native int zxid_idp_soap_parse(long jarg1, long jarg2, long jarg3, int jarg4, String jarg5);
  public final static native int zxid_anoint_a7n(long jarg1, int jarg2, long jarg3, String jarg4, String jarg5);
  public final static native long zxid_add_ldif_attrs(long jarg1, long jarg2, int jarg3, String jarg4, String jarg5);
  public final static native long zxid_gen_boots(long jarg1, String jarg2, String jarg3, long jarg4);
  public final static native long zxid_mk_user_a7n_to_sp(long jarg1, long jarg2, String jarg3, long jarg4, long jarg5, String jarg6, int jarg7);
  public final static native long zxid_check_fed(long jarg1, String jarg2, String jarg3, char jarg4, long jarg5, String jarg6, String jarg7, String jarg8);
  public final static native String zxid_add_fed_tok_to_epr(long jarg1, long jarg2, String jarg3);
  public final static native String zxid_idp_sso(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native long zxid_idp_as_do(long jarg1, long jarg2);
  public final static native int zxid_pick_sso_profile(long jarg1, long jarg2, long jarg3);
  public final static native int zxid_start_sso(long jarg1, long jarg2);
  public final static native String zxid_start_sso_url(long jarg1, long jarg2);
  public final static native String zxid_start_sso_location(long jarg1, long jarg2);
  public final static native int zxid_sp_deref_art(long jarg1, long jarg2, long jarg3);
  public final static native int zxid_sp_sso_finalize(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native int zxid_sp_anon_finalize(long jarg1, long jarg2, long jarg3);
  public final static native String zxid_saml2_map_nid_fmt(String jarg1);
  public final static native String zxid_saml2_map_protocol_binding(String jarg1);
  public final static native int zxid_protocol_binding_map_saml2(String jarg1);
  public final static native String zxid_saml2_map_authn_ctx(String jarg1);
  public final static native long zxid_issuer(long jarg1, String jarg2, String jarg3);
  public final static native void zxid_sigres_map(int jarg1, long jarg2, long jarg3);
  public final static native int zxid_validate_cond(long jarg1, long jarg2, long jarg3, long jarg4, String jarg5, long jarg6, long jarg7);
  public final static native int zxid_sp_slo_soap(long jarg1, long jarg2, long jarg3);
  public final static native String zxid_sp_slo_redir(long jarg1, long jarg2, long jarg3);
  public final static native int zxid_sp_slo_do(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native int zxid_idp_slo_do(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native String zxid_slo_resp_redir(long jarg1, long jarg2, long jarg3);
  public final static native int zxid_sp_mni_soap(long jarg1, long jarg2, long jarg3, String jarg4);
  public final static native String zxid_sp_mni_redir(long jarg1, long jarg2, long jarg3, String jarg4);
  public final static native long zxid_mni_do(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native String zxid_mni_do_ss(long jarg1, long jarg2, long jarg3, long jarg4, String jarg5);
  public final static native int zxid_pep_az_soap(long jarg1, long jarg2, long jarg3, String jarg4);
  public final static native int zxid_az_cf_ses(long jarg1, String jarg2, long jarg3);
  public final static native int zxid_az_cf(long jarg1, String jarg2, String jarg3);
  public final static native int zxid_az(String jarg1, String jarg2, String jarg3);
  public final static native long zxid_find_attribute(long jarg1, int jarg2, String jarg3, int jarg4, String jarg5, int jarg6, String jarg7, int jarg8);
  public final static native long zxid_mk_authn_req(long jarg1, long jarg2);
  public final static native long zxid_mk_art_deref(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_mk_Status(long jarg1, String jarg2, String jarg3, String jarg4);
  public final static native long zxid_OK(long jarg1);
  public final static native long zxid_mk_enc_id(long jarg1, long jarg2, long jarg3);
  public final static native long zxid_mk_enc_a7n(long jarg1, long jarg2, long jarg3);
  public final static native long zxid_mk_logout(long jarg1, long jarg2, String jarg3, long jarg4);
  public final static native long zxid_mk_logout_resp(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_mk_mni(long jarg1, long jarg2, String jarg3, long jarg4);
  public final static native long zxid_mk_mni_resp(long jarg1, long jarg2, String jarg3);
  public final static native long zxid_mk_a7n(long jarg1, String jarg2, long jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long zxid_mk_subj(long jarg1, long jarg2, long jarg3);
  public final static native long zxid_mk_an_stmt(long jarg1, long jarg2);
  public final static native long zxid_mk_saml_resp(long jarg1);
  public final static native long zxid_mk_xacml_resp(long jarg1, String jarg2);
  public final static native long zxid_mk_xacml_simple_at(long jarg1, long jarg2, String jarg3, String jarg4, String jarg5, String jarg6);
  public final static native long zxid_mk_az(long jarg1, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long zxid_mk_az_cd1(long jarg1, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long zxid_mk_attribute(long jarg1, String jarg2, String jarg3);
  public final static native long zxid_mk_lu_Status(long jarg1, String jarg2, String jarg3, String jarg4, String jarg5);
  public final static native long zxid_mk_di_query(long jarg1, String jarg2, String jarg3, String jarg4, String jarg5);
  public final static native long zxid_mk_addr(long jarg1, String jarg2);
  public final static native long zxid_mk_dap_select(long jarg1, String jarg2, String jarg3, String jarg4, int jarg5, int jarg6, int jarg7, int jarg8, int jarg9);
  public final static native long zxid_mk_dap_query_item(long jarg1, long jarg2, String jarg3, String jarg4, String jarg5, String jarg6, int jarg7, int jarg8, int jarg9, String jarg10, String jarg11, String jarg12);
  public final static native long zxid_mk_dap_testop(long jarg1, String jarg2, String jarg3, String jarg4, int jarg5, int jarg6, int jarg7, int jarg8, int jarg9);
  public final static native long zxid_mk_dap_test_item(long jarg1, long jarg2, String jarg3, String jarg4);
  public final static native long zxid_mk_dap_resquery(long jarg1, long jarg2, String jarg3, String jarg4, String jarg5, String jarg6, int jarg7, String jarg8);
  public final static native long zxid_mk_dap_subscription(long jarg1, String jarg2, String jarg3, long jarg4, String jarg5, String jarg6, String jarg7, String jarg8, int jarg9, String jarg10, String jarg11);
  public final static native long zxid_mk_dap_query(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native String zxid_wsp_validate(long jarg1, long jarg2, String jarg3, String jarg4);
  public final static native String zxid_wsp_decorate(long jarg1, long jarg2, String jarg3, String jarg4);
  public final static native String zxid_wsp_decoratef(long jarg1, long jarg2, String jarg3, String jarg4);
  public final static native long zxid_wsf_decor(long jarg1, long jarg2, long jarg3);
  public final static native int ZXID_N_WSF_SIGNED_HEADERS_get();
  public final static native int zxid_map_sec_mech(long jarg1);
  public final static native int zxid_add_header_refs(long jarg1, int jarg2, long jarg3, long jarg4);
  public final static native void zxid_wsf_sign(long jarg1, int jarg2, long jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long zxid_wsc_call(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native String zxid_call(long jarg1, long jarg2, String jarg3, String jarg4, String jarg5, String jarg6, String jarg7);
  public final static native String zxid_callf(long jarg1, long jarg2, String jarg3, String jarg4, String jarg5, String jarg6, String jarg7);
  public final static native int zxid_nice_sha1(long jarg1, String jarg2, int jarg3, String jarg4, String jarg5, int jarg6);
  public final static native void zxid_fold_svc(String jarg1, int jarg2);
  public final static native int zxid_epr_path(long jarg1, String jarg2, String jarg3, String jarg4, int jarg5, String jarg6, String jarg7);
  public final static native long zxid_get_epr(long jarg1, long jarg2, String jarg3, String jarg4, String jarg5, String jarg6, int jarg7);
  public final static native long zxid_find_epr(long jarg1, long jarg2, String jarg3, String jarg4, String jarg5, String jarg6, int jarg7);
  public final static native int zxid_cache_epr(long jarg1, long jarg2, long jarg3);
  public final static native void zxid_snarf_eprs_from_ses(long jarg1, long jarg2);
  public final static native String zxid_get_epr_address(long jarg1, long jarg2);
  public final static native String zxid_get_epr_entid(long jarg1, long jarg2);
  public final static native long zxid_di_query(long jarg1, long jarg2, long jarg3);
  public final static native int ZXID_DAP_SCOPE_BASE_get();
  public final static native int ZXID_DAP_SCOPE_SINGLE_get();
  public final static native int ZXID_DAP_SCOPE_SUBTREE_get();
  public final static native int ZXID_CDC_CHOICE_ALWAYS_FIRST_get();
  public final static native int ZXID_CDC_CHOICE_ALWAYS_LAST_get();
  public final static native int ZXID_CDC_CHOICE_ALWAYS_ONLY_get();
  public final static native int ZXID_CDC_CHOICE_UI_PREF_get();
  public final static native int ZXID_CDC_CHOICE_UI_NOPREF_get();
  public final static native int ZXID_CDC_CHOICE_UI_ONLY_CDC_get();
  public final static native int ZXID_SAML2_ART_get();
  public final static native int ZXID_SAML2_POST_get();
  public final static native int ZXID_SAML2_PAOS_get();
  public final static native int ZXID_SAML2_SOAP_get();
  public final static native int ZXID_SAML2_POST_SIMPLE_SIGN_get();
  public final static native int ZXID_SAML2_REDIR_get();
  public final static native int ZXID_SAML2_URI_get();
  public final static native int ZXID_SLO_SVC_get();
  public final static native int ZXID_MNI_SVC_get();
  public final static native int ZXID_ACS_SVC_get();
  public final static native int ZXID_SEC_MECH_NULL_get();
  public final static native int ZXID_SEC_MECH_BEARER_get();
  public final static native int ZXID_SEC_MECH_SAML_get();
  public final static native int ZXID_SEC_MECH_X509_get();
  public final static native int ZXID_SEC_MECH_PEERS_get();
  public final static native int ZXID_FAIL_get();
  public final static native int ZXID_OK_get();
  public final static native int ZXID_REDIR_OK_get();
  public final static native int ZXID_SSO_OK_get();
  public final static native int ZXID_IDP_REQ_get();
  public final static native String ZXID_TRUE_get();
  public final static native String ZXID_FALSE_get();
  public final static native String CRLF_get();
  public final static native String CRLF2_get();
  public final static native void std_basis_64_set(String jarg1);
  public final static native String std_basis_64_get();
  public final static native void safe_basis_64_set(String jarg1);
  public final static native String safe_basis_64_get();
  public final static native void zx_std_index_64_set(long jarg1);
  public final static native long zx_std_index_64_get();
  public final static native String base64_fancy_raw(String jarg1, int jarg2, String jarg3, String jarg4, int jarg5, int jarg6, String jarg7, char jarg8);
  public final static native String unbase64_raw(String jarg1, String jarg2, String jarg3, long jarg4);
  public final static native String sha1_safe_base64(String jarg1, int jarg2, String jarg3);
  public final static native String zx_zlib_raw_deflate(long jarg1, int jarg2, String jarg3, long jarg4);
  public final static native String zx_zlib_raw_inflate(long jarg1, int jarg2, String jarg3, long jarg4);
  public final static native int zx_url_encode_len(int jarg1, String jarg2);
  public final static native String zx_url_encode_raw(int jarg1, String jarg2, String jarg3);
  public final static native String zx_url_encode(long jarg1, int jarg2, String jarg3, long jarg4);
  public final static native void hex_trans_set(long jarg1);
  public final static native long hex_trans_get();
  public final static native void ykmodhex_trans_set(long jarg1);
  public final static native long ykmodhex_trans_get();
  public final static native String zx_hexdec(String jarg1, String jarg2, int jarg3, long jarg4);
  public final static native int read_all(int jarg1, String jarg2, String jarg3, String jarg4);
  public final static native int name_from_path(String jarg1, int jarg2, String jarg3);
  public final static native long open_fd_from_path(int jarg1, int jarg2, String jarg3, String jarg4);
  public final static native int read_all_fd(long jarg1, String jarg2, int jarg3, long jarg4);
  public final static native int write_all_fd(long jarg1, String jarg2, int jarg3);
  public final static native int write_all_path_fmt(String jarg1, int jarg2, String jarg3, String jarg4, String jarg5, String jarg6, String jarg7);
  public final static native int close_file(long jarg1, String jarg2);
  public final static native void zxid_curl_ctx_p_set(long jarg1, String jarg2);
  public final static native String zxid_curl_ctx_p_get(long jarg1);
  public final static native void zxid_curl_ctx_lim_set(long jarg1, String jarg2);
  public final static native String zxid_curl_ctx_lim_get(long jarg1);
  public final static native long new_zxid_curl_ctx();
  public final static native void delete_zxid_curl_ctx(long jarg1);
  public final static native long zxid_curl_write_data(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native long zxid_curl_read_data(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native String SAML2_PROTO_get();
  public final static native String SAML2_VERSION_get();
  public final static native String SAML2_SC_SUCCESS_get();
  public final static native String SAML2_SC_REQUESTER_get();
  public final static native String SAML2_SC_RESPONDER_get();
  public final static native String SAML2_SC_VERSION_get();
  public final static native String SAML2_SC_AUTHNFAIL_get();
  public final static native String SAML2_SC_INVATTRNV_get();
  public final static native String SAML2_SC_INVNIDPOL_get();
  public final static native String SAML2_SC_NOAUTNCTX_get();
  public final static native String SAML2_SC_NOAVALIDP_get();
  public final static native String SAML2_SC_NOPASSIVE_get();
  public final static native String SAML2_SC_NOSUPPIDP_get();
  public final static native String SAML2_SC_PARLOGOUT_get();
  public final static native String SAML2_SC_PROXYCEXC_get();
  public final static native String SAML2_SC_REQDENIED_get();
  public final static native String SAML2_SC_REQUNSUPP_get();
  public final static native String SAML2_SC_REQVERDEP_get();
  public final static native String SAML2_SC_REQVERHIG_get();
  public final static native String SAML2_SC_REQVERLOW_get();
  public final static native String SAML2_SC_RESONRECG_get();
  public final static native String SAML2_SC_TOOMNYRES_get();
  public final static native String SAML2_SC_UNKATTPRO_get();
  public final static native String SAML2_SC_UNKPRNCPL_get();
  public final static native String SAML2_SC_UNSUPPBIN_get();
  public final static native String SAML_AUTHCTX_PASSWORDPROTECTED_get();
  public final static native String SAML_AUTHCTX_PASSWORD_get();
  public final static native String SAML_AUTHCTX_SSL_TLS_CERT_get();
  public final static native String SAML_AUTHCTX_PREVSESS_get();
  public final static native String SAML_AUTHCTX_UNSPCFD_get();
  public final static native String SAML_AUTHCTX_INPROT_get();
  public final static native String SAML2_UNSPECIFIED_NID_FMT_get();
  public final static native String SAML2_EMAILADDR_NID_FMT_get();
  public final static native String SAML2_X509_NID_FMT_get();
  public final static native String SAML2_WINDOMAINQN_NID_FMT_get();
  public final static native String SAML2_KERBEROS_NID_FMT_get();
  public final static native String SAML2_ENTITY_NID_FMT_get();
  public final static native String SAML2_PERSISTENT_NID_FMT_get();
  public final static native String SAML2_TRANSIENT_NID_FMT_get();
  public final static native String SAML2_SSO_BRWS_get();
  public final static native String SAML2_SSO_ECP_get();
  public final static native String SAML2_SLO_get();
  public final static native String SAML2_NIREG_get();
  public final static native String SAML2_NIMAP_get();
  public final static native String SAML2_ARTIFACT_get();
  public final static native String SAML2_QUERY_get();
  public final static native String SAML2_PAOS_get();
  public final static native String SAML2_SOAP_get();
  public final static native String SAML2_REDIR_get();
  public final static native String SAML2_ART_get();
  public final static native String SAML2_POST_get();
  public final static native String SAML2_POST_SIMPLE_SIGN_get();
  public final static native String SAML2_URI_get();
  public final static native String SAML2_AP_BASIC_get();
  public final static native String SAML2_AP_X500_get();
  public final static native String SAML2_AP_UUID_get();
  public final static native String SAML2_AP_DCE_get();
  public final static native String SAML2_AP_XACML_get();
  public final static native String ATTRNAME_UNSPECIFIED_get();
  public final static native String ATTRNAME_BASIC_get();
  public final static native String SOAP_ACTOR_NEXT_get();
  public final static native String SAML2_BEARER_get();
  public final static native String SAML2_SOAP_ACTION_get();
  public final static native String ACTION_RW_get();
  public final static native String ACTION_RWN_get();
  public final static native String ACTION_GHPP_get();
  public final static native String ACTION_UNIX_get();
  public final static native String PAOS_CONTENT_get();
  public final static native String XMLNS_SA_get();
  public final static native String XMLNS_IMS_get();
  public final static native String XMLNS_LIB_get();
  public final static native String ACT_SASL_REQ_get();
  public final static native String ACT_SASL_RES_get();
  public final static native String PWTRUNCATE_get();
  public final static native String PWLOWERCASE_get();
  public final static native String PWUPPERCASE_get();
  public final static native String PWSELECT_get();
  public final static native String XMLNS_SUBS_get();
  public final static native String XMLNS_SUBSREF_get();
  public final static native String SUBS_OPT_NOSUBSCIB_get();
  public final static native String SUBS_OPT_NOQUESUBS_get();
  public final static native String SUBS_END_EXPIRED_get();
  public final static native String SUBS_END_DELETED_get();
  public final static native String WSF11_DI_RO_get();
  public final static native String WSF20_DI_RO_get();
  public final static native String IMPLIED_RSC_get();
  public final static native String XMLNS_DISCO_1_1_get();
  public final static native String XMLNS_DISCO_EXT_get();
  public final static native String XMLNS_DISCO_2_0_get();
  public final static native String XMLNS_SBF_get();
  public final static native String ACT_QUE_get();
  public final static native String ACT_QUE_RES_get();
  public final static native String ACT_ASSO_QUE_get();
  public final static native String ACT_ASSO_QUE_RES_get();
  public final static native String ACT_ASSO_ADD_get();
  public final static native String ACT_ASSO_ADD_RES_get();
  public final static native String ACT_ASSO_DEL_get();
  public final static native String ACT_ASSO_DEL_RES_get();
  public final static native String ACT_SVCMD_QUE_get();
  public final static native String ACT_SVCMD_QUE_RES_get();
  public final static native String ACT_SVCMD_REG_get();
  public final static native String ACT_SVCMD_REG_RES_get();
  public final static native String ACT_SVCMD_REP_get();
  public final static native String ACT_SVCMD_REP_RES_get();
  public final static native String ACT_SVCMD_DEL_get();
  public final static native String ACT_SVCMD_DEL_RES_get();
  public final static native String XMLNS_GL_get();
  public final static native String GL_OPT_SHAPE_get();
  public final static native String GL_OPT_SPEED_get();
  public final static native String GL_OPT_DIRECTION_get();
  public final static native String GL_OPT_HEADING_get();
  public final static native String GL_OPT_ALT_get();
  public final static native String GL_OPT_CIVIL_DATA_get();
  public final static native String GL_OPT_AC_get();
  public final static native String GL_OPT_AC_ONLY_get();
  public final static native String GL_OPT_ACC_HIGH_get();
  public final static native String GL_OPT_ACC_MEDIUM_get();
  public final static native String GL_OPT_ACC_LOW_get();
  public final static native String XMLNS_IS11_get();
  public final static native String XMLNS_IS20_get();
  public final static native String ACT_IREQ_get();
  public final static native String ACT_IRES_get();
  public final static native String OPT_PP_get();
  public final static native String OPT_PP_INAME_get();
  public final static native String OPT_PP_CN_get();
  public final static native String OPT_PP_LEG_get();
  public final static native String OPT_PP_ADD_get();
  public final static native String OPTC_PP_get();
  public final static native String OPTC_PP_INAME_get();
  public final static native String OPTC_PP_CN_get();
  public final static native String OPTC_PP_LEG_get();
  public final static native String OPTC_PP_ADD_get();
  public final static native String OPT_MULT_QI_get();
  public final static native String OPT_MULT_MI_get();
  public final static native String XMLNS_PP_get();
  public final static native String PS_COL_get();
  public final static native String PS_ENT_get();
  public final static native String XMLNS_PS_get();
  public final static native String ACT_PS_ADDENT_REQ_get();
  public final static native String ACT_PS_ADDENT_RES_get();
  public final static native String ACT_PS_ADDKENT_REQ_get();
  public final static native String ACT_PS_ADDKENT_RES_get();
  public final static native String ACT_PS_REMENT_REQ_get();
  public final static native String ACT_PS_REMENT_RES_get();
  public final static native String ACT_PS_ADDCOL_REQ_get();
  public final static native String ACT_PS_ADDCOL_RES_get();
  public final static native String ACT_PS_REMCOL_REQ_get();
  public final static native String ACT_PS_REMCOL_RES_get();
  public final static native String ACT_PS_ADDTOCOL_REQ_get();
  public final static native String ACT_PS_ADDTOCOL_RES_get();
  public final static native String ACT_PS_REMFROMCOL_REQ_get();
  public final static native String ACT_PS_REMFROMCOL_RES_get();
  public final static native String ACT_PS_LISTMEM_REQ_get();
  public final static native String ACT_PS_LISTMEM_RES_get();
  public final static native String ACT_PS_GETOBJ_REQ_get();
  public final static native String ACT_PS_GETOBJ_RES_get();
  public final static native String ACT_PS_SETOBJ_REQ_get();
  public final static native String ACT_PS_SETOBJ_RES_get();
  public final static native String ACT_PS_QUEOBJ_REQ_get();
  public final static native String ACT_PS_QUEOBJ_RES_get();
  public final static native String ACT_PS_TESTMEM_REQ_get();
  public final static native String ACT_PS_TESTMEM_RES_get();
  public final static native String ACT_PS_RSLVID_REQ_get();
  public final static native String ACT_PS_RSLVID_RES_get();
  public final static native String ACT_PS_NOTIFY_get();
  public final static native String ACT_PS_NOTIFY_RES_get();
  public final static native String XMLNS_SEC_get();
  public final static native String TOKNUSG_SEC_get();
  public final static native String TOKNUSG_TID_get();
  public final static native String TOKNUSG_IID_get();
  public final static native String WSF10_SEC_MECH_NULL_BEARER_get();
  public final static native String WSF10_SEC_MECH_TLS_BEARER_get();
  public final static native String WSF11_SEC_MECH_NULL_NULL_get();
  public final static native String WSF11_SEC_MECH_TLS_NULL_get();
  public final static native String WSF11_SEC_MECH_CLTLS_NULL_get();
  public final static native String WSF11_SEC_MECH_NULL_BEARER_get();
  public final static native String WSF11_SEC_MECH_TLS_BEARER_get();
  public final static native String WSF11_SEC_MECH_CLTLS_BEARER_get();
  public final static native String WSF11_SEC_MECH_NULL_X509_get();
  public final static native String WSF11_SEC_MECH_TLS_X509_get();
  public final static native String WSF11_SEC_MECH_CLTLS_X509_get();
  public final static native String WSF11_SEC_MECH_NULL_SAML_get();
  public final static native String WSF11_SEC_MECH_TLS_SAML_get();
  public final static native String WSF11_SEC_MECH_CLTLS_SAML_get();
  public final static native String WSF20_SEC_MECH_NULL_NULL_get();
  public final static native String WSF20_SEC_MECH_TLS_NULL_get();
  public final static native String WSF20_SEC_MECH_NULL_BEARER_get();
  public final static native String WSF20_SEC_MECH_TLS_BEARER_get();
  public final static native String WSF20_SEC_MECH_NULL_SAML2_get();
  public final static native String WSF20_SEC_MECH_TLS_SAML2_get();
  public final static native String WSF20_SEC_MECH_CLTLS_SAML2_get();
  public final static native String WSF20_SEC_MECH_CLTLS_PEERS2_get();
  public final static native String SAML2_TOK_PROFILE_get();
  public final static native String SAMLID_TOK_PROFILE_get();
  public final static native String WSS_X509_TOKEN_PROFILE_get();
  public final static native String SB_EPUPD_COMP_get();
  public final static native String SB_EPUPD_PART_get();
  public final static native String SB_EPUPD_NOCH_get();
  public final static native String A_ANON_get();
  public final static native String XMLNS_CSM_get();
  public final static native String XMLNS_LU_get();
  public final static native String XMLNS_HLO_get();
  public final static native String DST_ACC_CHALLENGE_get();
  public final static native String XMLNS_CXP_get();
  public final static native String XMLNS_LIB_MD_get();
  public final static native String XMLNS_AC_get();
  public final static native String LIBERTY_NAMEID_FMT_FED_get();
  public final static native String LIBERTY_NAMEID_FMT_ONE_get();
  public final static native String LIBERTY_NAMEID_FMT_ENC_get();
  public final static native String LIBERTY_NAMEID_FMT_ENT_get();
  public final static native String XMLNS_PAOS_get();
  public final static native String PAOS_HDR_get();
  public final static native String LIBERTY_ENA_HDR_get();
  public final static native String LIBERTY_CONSENT_OBTAINED_get();
  public final static native String XMLNS_DAP_get();
  public final static native int ZXID_VERSION_get();
  public final static native String ZXID_REL_get();
  public final static native String ZXID_COMPILE_DATE_get();
  public final static native void zx_ns_tab_set(long jarg1);
  public final static native long zx_ns_tab_get();
  public final static native int zx_xmlns_ix_ds_get();
  public final static native String zx_xmlns_ds_get();
  public final static native int zx_xmlns_ix_xenc_get();
  public final static native String zx_xmlns_xenc_get();
  public final static native int zx_xmlns_ix_exca_get();
  public final static native String zx_xmlns_exca_get();
  public final static native int zx_xmlns_ix_sa_get();
  public final static native String zx_xmlns_sa_get();
  public final static native int zx_xmlns_ix_sp_get();
  public final static native String zx_xmlns_sp_get();
  public final static native int zx_xmlns_ix_ecp_get();
  public final static native String zx_xmlns_ecp_get();
  public final static native int zx_xmlns_ix_paos_get();
  public final static native String zx_xmlns_paos_get();
  public final static native int zx_xmlns_ix_e_get();
  public final static native String zx_xmlns_e_get();
  public final static native int zx_xmlns_ix_md_get();
  public final static native String zx_xmlns_md_get();
  public final static native int zx_xmlns_ix_shibmd_get();
  public final static native String zx_xmlns_shibmd_get();
  public final static native int zx_xmlns_ix_sp11_get();
  public final static native String zx_xmlns_sp11_get();
  public final static native int zx_xmlns_ix_sa11_get();
  public final static native String zx_xmlns_sa11_get();
  public final static native int zx_xmlns_ix_ff12_get();
  public final static native String zx_xmlns_ff12_get();
  public final static native int zx_xmlns_ix_ac_get();
  public final static native String zx_xmlns_ac_get();
  public final static native int zx_xmlns_ix_m20_get();
  public final static native String zx_xmlns_m20_get();
  public final static native int zx_xmlns_ix_a_get();
  public final static native String zx_xmlns_a_get();
  public final static native int zx_xmlns_ix_wsse_get();
  public final static native String zx_xmlns_wsse_get();
  public final static native int zx_xmlns_ix_wsu_get();
  public final static native String zx_xmlns_wsu_get();
  public final static native int zx_xmlns_ix_sbf_get();
  public final static native String zx_xmlns_sbf_get();
  public final static native int zx_xmlns_ix_b_get();
  public final static native String zx_xmlns_b_get();
  public final static native int zx_xmlns_ix_sec_get();
  public final static native String zx_xmlns_sec_get();
  public final static native int zx_xmlns_ix_di_get();
  public final static native String zx_xmlns_di_get();
  public final static native int zx_xmlns_ix_is_get();
  public final static native String zx_xmlns_is_get();
  public final static native int zx_xmlns_ix_lu_get();
  public final static native String zx_xmlns_lu_get();
  public final static native int zx_xmlns_ix_dap_get();
  public final static native String zx_xmlns_dap_get();
  public final static native int zx_xmlns_ix_subs_get();
  public final static native String zx_xmlns_subs_get();
  public final static native int zx_xmlns_ix_dst_get();
  public final static native String zx_xmlns_dst_get();
  public final static native int zx_xmlns_ix_im_get();
  public final static native String zx_xmlns_im_get();
  public final static native int zx_xmlns_ix_ps_get();
  public final static native String zx_xmlns_ps_get();
  public final static native int zx_xmlns_ix_as_get();
  public final static native String zx_xmlns_as_get();
  public final static native int zx_xmlns_ix_xml_get();
  public final static native String zx_xmlns_xml_get();
  public final static native int zx_xmlns_ix_xsi_get();
  public final static native String zx_xmlns_xsi_get();
  public final static native int zx_xmlns_ix_xs_get();
  public final static native String zx_xmlns_xs_get();
  public final static native int zx_xmlns_ix_mm7_get();
  public final static native String zx_xmlns_mm7_get();
  public final static native int zx_xmlns_ix_cb_get();
  public final static native String zx_xmlns_cb_get();
  public final static native int zx_xmlns_ix_cdm_get();
  public final static native String zx_xmlns_cdm_get();
  public final static native int zx_xmlns_ix_gl_get();
  public final static native String zx_xmlns_gl_get();
  public final static native int zx_xmlns_ix_dp_get();
  public final static native String zx_xmlns_dp_get();
  public final static native int zx_xmlns_ix_idp_get();
  public final static native String zx_xmlns_idp_get();
  public final static native int zx_xmlns_ix_pmm_get();
  public final static native String zx_xmlns_pmm_get();
  public final static native int zx_xmlns_ix_prov_get();
  public final static native String zx_xmlns_prov_get();
  public final static native int zx_xmlns_ix_shps_get();
  public final static native String zx_xmlns_shps_get();
  public final static native int zx_xmlns_ix_hrxml_get();
  public final static native String zx_xmlns_hrxml_get();
  public final static native int zx_xmlns_ix_idhrxml_get();
  public final static native String zx_xmlns_idhrxml_get();
  public final static native int zx_xmlns_ix_demomed_get();
  public final static native String zx_xmlns_demomed_get();
  public final static native int zx_xmlns_ix_b12_get();
  public final static native String zx_xmlns_b12_get();
  public final static native int zx_xmlns_ix_sec12_get();
  public final static native String zx_xmlns_sec12_get();
  public final static native int zx_xmlns_ix_di12_get();
  public final static native String zx_xmlns_di12_get();
  public final static native int zx_xmlns_ix_is12_get();
  public final static native String zx_xmlns_is12_get();
  public final static native int zx_xmlns_ix_xac_get();
  public final static native String zx_xmlns_xac_get();
  public final static native int zx_xmlns_ix_xa_get();
  public final static native String zx_xmlns_xa_get();
  public final static native int zx_xmlns_ix_xasa_get();
  public final static native String zx_xmlns_xasa_get();
  public final static native int zx_xmlns_ix_xasp_get();
  public final static native String zx_xmlns_xasp_get();
  public final static native int zx_xmlns_ix_xaspcd1_get();
  public final static native String zx_xmlns_xaspcd1_get();
  public final static native int zx_xmlns_ix_xasacd1_get();
  public final static native String zx_xmlns_xasacd1_get();
  public final static native int zx_xmlns_ix_wst_get();
  public final static native String zx_xmlns_wst_get();
  public final static native int zx_xmlns_ix_wsp_get();
  public final static native String zx_xmlns_wsp_get();
  public final static native int zx_xmlns_ix_wsc_get();
  public final static native String zx_xmlns_wsc_get();
  public final static native int zx_xmlns_ix_tas3_get();
  public final static native String zx_xmlns_tas3_get();
  public final static native int zx_xmlns_ix_tas3sol_get();
  public final static native String zx_xmlns_tas3sol_get();
}
